@@ -315,6 +315,26 @@ t2body (MimeDataProvider *provider, rfc822parse_t msg)
     charset = NULL;
   }
 
+  if (!strcmp (ctmain, "multipart") || !strcmp (ctmain, "text"))
+    {
+      s = rfc822parse_query_parameter (field,
+                                       "protected-headers", -1);
+      if (s)
+        {
+          log_data ("%s:%s: Found protected headers: '%s'",
+                           SRCNAME, __func__, s);
+          if (!strncmp (s, "v", 1))
+            {
+              provider->m_protected_headers_version = atoi (s + 1);
+            }
+          is_protected_headers = 1;
+        }
+      else
+        {
+          is_protected_headers = 0;
+        }
+    }
+
   if (!strcmp (ctmain, "multipart"))
     {
       /* We don't care about the top level multipart layer but wait
@@ -351,22 +371,6 @@ t2body (MimeDataProvider *provider, rfc822parse_t msg)
   else if (!strcmp (ctmain, "text"))
     {
       is_text = !strcmp (ctsub, "html")? 2:1;
-      s = rfc822parse_query_parameter (field,
-                                       "protected-headers", -1);
-      if (s)
-        {
-          log_data ("%s:%s: Found protected headers: '%s'",
-                           SRCNAME, __func__, s);
-          if (!strncmp (s, "v", 1))
-            {
-              provider->m_protected_headers_version = atoi (s + 1);
-            }
-          is_protected_headers = 1;
-        }
-      else
-        {
-          is_protected_headers = 0;
-        }
     }
   else if (ctx->nesting_level == 1 && !provider->signature()
            && !strcmp (ctmain, "application")
@@ -1161,12 +1165,12 @@ void MimeDataProvider::finalize ()
 {
   TSTART;
 
+  static std::vector<std::string> user_headers = {"Subject", "From",
+                                                  "To", "Cc", "Date",
+                                                  "Reply-To",
+                                                  "Followup-To"};
   if (m_protected_headers_version)
     {
-      static std::vector<std::string> user_headers = {"Subject", "From",
-                                                      "To", "Cc", "Date",
-                                                      "Reply-To",
-                                                      "Followup-To"};
       for (const auto &hdr: user_headers)
         {
           m_protected_headers.emplace (hdr, get_header (m_mime_ctx->msg, hdr));
@@ -1188,6 +1192,26 @@ void MimeDataProvider::finalize ()
     {
       log_debug ("%s:%s: Detected protected headers legacy part. It will be hidden.",
                  SRCNAME, __func__);
+      if (m_protected_headers.empty ())
+        {
+          /* Do a simple parsing of the header data that is displayed. */
+          log_data ("Parsing headers from the legacy part.");
+          std::istringstream ss(m_ph_helpbuf);
+          std::string line;
+          while (std::getline (ss, line))
+            {
+              for (const auto &hdr: user_headers)
+                {
+                  const std::string needle = hdr + std::string (": ");
+                  if (starts_with (line, needle.c_str ()))
+                    {
+                      log_data ("Found line starting with: %s", needle.c_str ());
+                      find_and_replace (line, needle, std::string ());
+                      m_protected_headers.emplace (hdr, line);
+                    }
+                }
+            }
+        }
       log_data ("%s:%s: PH legacy part: '%s'", SRCNAME, __func__, m_ph_helpbuf.c_str ());
     }
   else if (m_ph_helpbuf.size ())
